from django.contrib.auth.base_user import AbstractBaseUser
from django.contrib.auth.models import PermissionsMixin
from django.db import models
from django.urls import reverse
from markdownx.models import MarkdownxField
from markdownx.utils import markdownify
from .managers import UserManager


class User(AbstractBaseUser, PermissionsMixin):
    username = models.CharField(max_length=32, unique=True, blank=False, null=False)
    email = models.EmailField(max_length=255, blank=True, null=True)

    is_staff = models.BooleanField(default=False)
    is_superuser = models.BooleanField(default=False)
    is_active = models.BooleanField(default=True)

    USERNAME_FIELD = 'username'

    objects = UserManager()

    def clean(self):
        super().clean()
        self.email = self.__class__.objects.normalize_email(self.email)

    def get_short_name(self):
        return f'{self.username}'

    def get_full_name(self):
        return f'{self.username} <{self.email}>'


class Post(models.Model):
    title = models.CharField(max_length=200, blank=True, null=True)
    body = MarkdownxField()
    created = models.DateTimeField(auto_now_add=True)
    modified = models.DateTimeField(auto_now=True)
    author = models.ForeignKey(User, on_delete=models.PROTECT)

    def body_display(self):
        return markdownify(self.body)

    def get_absolute_url(self):
        return reverse('core:post_detail', args=[self.id])

    def __str__(self):
        if self.title is not None:
            return self.title[0:50]
        else:
            return f'[{self.created}] {self.body[0:40]}'
