from django.conf import settings
from django.contrib.auth.mixins import LoginRequiredMixin
from django.shortcuts import render
from django.views.generic.detail import DetailView
from django.views.generic.edit import CreateView
from .models import Post, User
from .forms import UserCreationForm


def home_view(request):
    return render(request, 'home')


def dashboard_view(request):
    return render(request, 'dashboard')


class CreateUserView(CreateView):
    model = User
    template_name = 'registration/register'
    success_url = settings.LOGIN_URL
    form_class = UserCreationForm


class PostDetailView(DetailView):
    model = Post
    template_name = 'post/detail'


class CreatePostView(LoginRequiredMixin, CreateView):
    model = Post
    template_name = 'post/create'
    fields = ['title', 'body']

    def form_valid(self, form):
        form.instance.author = self.request.user
        return super().form_valid(form)
